==> free-sa-1.2.1.tar.gz: free-sa-1.2.1/src/reports/r_userdatetime.c <==
#include "global.h"


double yBytes[5][12][31][24];


void ReportDateTime(FILE *ifile, double *mBytes, double tBytes) {
    short int j, year, month, day, hour;
    double dBytes, hBytes[24];
    struct tm ttm;
    char dayFlag; /* for speed up */
    
    fprintf(ifile, "<tr><th>%s<th>00:00<th>01:00<th>02:00<th>03:00<th>04:00<th>05:00<th>06:00<th>07:00<th>08:00<th>09:00<th>10:00<th>11:00<th>12:00<th>13:00<th>14:00<th>15:00<th>16:00<th>17:00<th>18:00<th>19:00<th>20:00<th>21:00<th>22:00<th>23:00<th>%s\n", loc->DsT, loc->Bytes);

    memset(hBytes, 0, 24L * sizeof(double));
    memset(mBytes, 0, 31L * sizeof(double));
    
    for (year = 0; year <= icfg.EYear - icfg.SYear; year++)
	for (month = 0; month < 12; month++)
	    for (day = 0; day < 31; day++) {
		dBytes = 0;
		dayFlag = 0;
		for (hour = 0; hour < 24; hour++) {
		    if (yBytes[year][month][day][hour]) {
			/* If just detected that day have bytes */
			if (!dayFlag) {
			    dayFlag++;
			    
			    ttm.tm_year = year + icfg.SYear;
			    ttm.tm_mon = month;
			    ttm.tm_mday = day + 1;
			    
			    fprintf(ifile, "<tr><th>%s", GetD(&ttm, "%x"));
			    for (j = 0; j < hour; j++) fwrite("<td>0", 5L, 1L, ifile);
			}
			
			hBytes[hour] += yBytes[year][month][day][hour];
			dBytes += yBytes[year][month][day][hour];
			
			fprintf(ifile, "<td>%'.0f", yBytes[year][month][day][hour]);
		    /* If day have bytes, but hour not */
		    } else if (dayFlag) fwrite("<td>0", 5L, 1L, ifile);
		}
		
		/* If day has bytes */
		if (dayFlag) {
		    fprintf(ifile, "<th class=rt>%'.0f\n", dBytes);
		    mBytes[day] += dBytes;
		}
		
	    }
    
    fprintf(ifile, "<tr><th>%s<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f",
    loc->Bytes, hBytes[0], hBytes[1], hBytes[2], hBytes[3], hBytes[4], hBytes[5], hBytes[6], hBytes[7], hBytes[8], hBytes[9], hBytes[10], hBytes[11], hBytes[12], hBytes[13], hBytes[14], hBytes[15], hBytes[16], hBytes[17], hBytes[18], hBytes[19], hBytes[20], hBytes[21], hBytes[22], hBytes[23], tBytes);
}


void ReportUserDateTime(int i, double *mBytes) {
    FILE *UDR;
    char stext[128];


    sprintf(stext, "%s (%s)", loc->DsT, loc->Asc);
    UDR = SAfopenH("../", 'r', Users[i].vname, stext, 1, "w", "%s/d_%s.html", icfg.ReportDir, Users[i].name);
    ReportDateTime(UDR, mBytes, Users[i].Bytes);
    SAfcloseH(UDR, Users[i].fname);
}

==> free-sa-1.2.4.tar.gz: free-sa-1.2.4/src/reports/r_userdatetime.c <==
#include "global.h"


double yBytes[5][12][31][24];


void ReportDateTime(FILE *ifile, double *mBytes, double tBytes) {
    short int j, year, month, day, hour;
    double dBytes, hBytes[24];
    struct tm ttm;
    char dayFlag; /* for speed up */
    
    fprintf(ifile, "<tr><th>%s<th>00:00<th>01:00<th>02:00<th>03:00<th>04:00<th>05:00<th>06:00<th>07:00<th>08:00<th>09:00<th>10:00<th>11:00<th>12:00<th>13:00<th>14:00<th>15:00<th>16:00<th>17:00<th>18:00<th>19:00<th>20:00<th>21:00<th>22:00<th>23:00<th>%s\n", loc->DsT, loc->Bytes);

    memset(hBytes, 0, 24L * sizeof(double));
    memset(mBytes, 0, 31L * sizeof(double));
    
    for (year = 0; year <= icfg.EYear - icfg.SYear; year++)
	for (month = 0; month < 12; month++)
	    for (day = 0; day < 31; day++) {
		dBytes = 0;
		dayFlag = 0;
		for (hour = 0; hour < 24; hour++) {
		    if (yBytes[year][month][day][hour]) {
			/* If just detected that day have bytes */
			if (!dayFlag) {
			    dayFlag++;
			    
			    ttm.tm_year = year + icfg.SYear;
			    ttm.tm_mon = month;
			    ttm.tm_mday = day + 1;
			    
			    fprintf(ifile, "<tr><th>%s", GetD(&ttm, "%x"));
			    for (j = 0; j < hour; j++) fwrite("<td>0", 5L, 1L, ifile);
			}
			
			hBytes[hour] += yBytes[year][month][day][hour];
			dBytes += yBytes[year][month][day][hour];
			
			fprintf(ifile, "<td>%'.0f", yBytes[year][month][day][hour]);
		    /* If day have bytes, but hour not */
		    } else if (dayFlag) fwrite("<td>0", 5L, 1L, ifile);
		}
		
		/* If day has bytes */
		if (dayFlag) {
		    fprintf(ifile, "<th class=rt>%'.0f\n", dBytes);
		    mBytes[day] += dBytes;
		}
		
	    }
    
    fprintf(ifile, "<tr><th>%s<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f<th class=rt>%'.0f",
    loc->Bytes, hBytes[0], hBytes[1], hBytes[2], hBytes[3], hBytes[4], hBytes[5], hBytes[6], hBytes[7], hBytes[8], hBytes[9], hBytes[10], hBytes[11], hBytes[12], hBytes[13], hBytes[14], hBytes[15], hBytes[16], hBytes[17], hBytes[18], hBytes[19], hBytes[20], hBytes[21], hBytes[22], hBytes[23], tBytes);
}


void ReportUserDateTime(int i, double *mBytes) {
    FILE *UDR;
    char stext[128];


    snprintf(stext, sizeof(stext), "%s (%s)", loc->DsT, loc->Asc);
    UDR = SAfopenH("../", 'r', Users[i].vname, stext, 1, "w", "%s/d_%s.html", icfg.ReportDir, Users[i].name);
    ReportDateTime(UDR, mBytes, Users[i].Bytes);
    SAfcloseH(UDR, Users[i].fname);
}
